﻿local obj = {}
local players = {}

---------------------1------2------3--------4-------5-----6-----7--------8-------9--
--{ players[N] = { BODY, SHAPE, FIXTURE, SENSOR, LEFT, RIGHT, JUMP, ON_GROUND, COUNT }

function createPlayer(x, y)
	if #players < 5 then
		local nPlayer = #players+1
		players[nPlayer] = {}
		local body = love.physics.newBody( level, x, y, 'dynamic' )
		local pShape = love.physics.newPolygonShape( 0.25, 0.4, 0.75, 0.4, 1, 0.65, 1, 1.75, 0.75, 2, 0.25, 2, 0, 1.75, 0, 0.65 )
		--body:setGravityScale(0)
		body:setFixedRotation(true)
		local fixture = love.physics.newFixture( body, pShape, 1 )
		fixture:setFriction(1)
		fixture:setRestitution(0)
		local sShape = love.physics.newRectangleShape( 0.26, 1.9, 0.48, 0.5, 0 )
		local sensor = love.physics.newFixture( body, sShape, 1 )
		sensor:setSensor( true )
		sensor:setFriction(1)
		sensor:setRestitution(0)
		body:setMassData( 0.5, 1, 80, 0 )
		players[nPlayer] = { body, pShape, fixture, sensor, false, false, 0, false, 0 }
	end
end


function createPlatform(x, y)
	local body = love.physics.newBody( level, x, y, 'static' )
	local v = love.physics.newChainShape( true, 0, 0, 0, 1, 1, 1, 1, 0 )
	body:setGravityScale( 0 )
	love.physics.newFixture( body, v, 1 )
	  return body
end

function createRamp(x, y)
	local body = love.physics.newBody( level, x, y, 'static' )
	local v = love.physics.newChainShape( true, 1, 0, 0, 1, 1, 1 )
	body:setGravityScale( 0 )
	love.physics.newFixture( body, v, 1 )
	  return body
end

function love.load()
	love.window.setMode(800, 600)
	--love.graphics.setBackgroundColor( 250, 250, 250 )
	level = love.physics.newWorld(0, 918, true)
	level:setCallbacks( beginContact, endContact, preSolve, postSolve )
	love.physics.setMeter( 1 )
		
		for x = 0, 7 do
			obj[#obj+1] = createPlatform(x, 6)
		end

		for x = 0, 7 do
			obj[#obj+1] = createPlatform(x, 2)
		end	
		
		obj[#obj+1] = createRamp(6 , 5 )
		obj[#obj+1] = createPlatform(7 , 5 )
	
		createPlayer( 3, 2 )
		
end

function beginContact(a, b)
	if a == players[1][4] or b == players[1][4] then
		players[1][9] = players[1][9] + 1
		players[1][8] = true
	end
end

function endContact(a, b)
	if a == players[1][4] or b == players[1][4] then
		players[1][9] = players[1][9] - 1
			if players[1][9] <= 0 then
				players[1][8] = false
			end
	end
end

function love.update(dt)
	level:update(dt)
	checkInput(dt)
end

local vX, vY = 0, 0

function checkInput( dt )
	if players[1] then
		local _, dy = (players[1][1]):getLinearVelocity()
		local dx = 0
		if love.keyboard.isDown("a")  then
			players[1][5] = true
		else
			players[1][5] = false
		end
		if love.keyboard.isDown("d")  then
			players[1][6] = true
		else
			players[1][6] = false
		end
		--[[if love.keyboard.isDown("w")  then
			if players[1][8] then
				players[1][7] = players[1][7] - 10
			end
		end]]
				if players[1][5] and not players[1][6] then
					if players[1][8] then
						dx = -10
					else
						dx = -7.5
					end
				end				
				if players[1][6] and not players[1][5] then
					if players[1][8] then
						dx = 10
					else
						dx = 7.5
					end
				end
		--[[if not players[1][8] then
			players[1][7] = math.min(players[1][7] + (25*dt), 15 )
		end]]
		--local dx, dy = (players[1][1]):getLinearVelocity()
		(players[1][1]):setLinearVelocity( dx, dy )
	end
end

function love.draw()
	for _, body in ipairs( obj ) do
		x1, y1, x2, y2, x3, y3, x4, y4 = body:getWorldPoints( (((body:getFixtureList())[1]):getShape()):getPoints() )
		love.graphics.polygon( 'line', x1*64, y1*64, x2*64, y2*64, x3*64, y3*64, x4*64, y4*64 )
	end
	for _, player in ipairs( players ) do
		x1, y1, x2, y2, x3, y3, x4, y4, x5, y5, x6, y6, x7, y7, x8, y8 = (player[1]):getWorldPoints( (player[2]):getPoints() )
		love.graphics.polygon( 'line', x1*64, y1*64, x2*64, y2*64, x3*64, y3*64, x4*64, y4*64, x5*64, y5*64, x6*64, y6*64, x7*64, y7*64, x8*64, y8*64 )
	end
	love.graphics.print("On ground: "..tostring(players[1][8]), 10, 33)
	love.graphics.print("Count: "..tostring(players[1][9]), 10, 46)
	love.graphics.print("Jump: "..tostring(players[1][7]), 10, 59)
	love.graphics.print(("Velocity: %s, %s"):format((players[1][1]):getLinearVelocity()), 10, 72)
end